@@ -14,11 +14,11 @@
 #'  \item \code{percentage}: approximate percentage error of marginal likelihood estimate.
 #' }
 #' If \code{bridge_object} is of class \code{"bridge_list"}, returns a list with components:
-  #' \itemize{
-  #'  \item \code{min}: minimum of the log marginal likelihood estimates.
-  #'  \item \code{max}: maximum of the log marginal likelihood estimates.
-  #'  \item \code{IQR}: interquartile range of the log marginal likelihood estimates.
-  #' }
+#' \itemize{
+#'  \item \code{min}: minimum of the log marginal likelihood estimates.
+#'  \item \code{max}: maximum of the log marginal likelihood estimates.
+#'  \item \code{IQR}: interquartile range of the log marginal likelihood estimates.
+#' }
 #' @author Quentin F. Gronau
 #' @note For examples, see \code{\link{bridge_sampler}} and the accompanying vignettes: \cr \code{vignette("bridgesampling_example_jags")} \cr \code{vignette("bridgesampling_example_stan")}
 #'
@@ -29,42 +29,43 @@
 #' @import Brobdingnag
 #' @importFrom coda spectrum0.ar
 #' @export
-error_measures <- function (bridge_object, ...) {
+error_measures <- function(bridge_object, ...) {
   UseMethod("error_measures", bridge_object)
 }
 
 #' @rdname error_measures
 #' @export
-error_measures.bridge <- function(bridge_object,...) {
-
+error_measures.bridge <- function(bridge_object, ...) {
   if (bridge_object$method == "warp3") {
-    stop(paste0("error_measures not implemented for warp3 method with",
-                "\n  repetitions = 1.",
-                "\n  We recommend to run the warp3 procedure multiple times",
-                "\n  to assess the uncertainty of the estimate."))
+    stop(paste0(
+      "error_measures not implemented for warp3 method with",
+      "\n  repetitions = 1.",
+      "\n  We recommend to run the warp3 procedure multiple times",
+      "\n  to assess the uncertainty of the estimate."
+    ))
   }
 
-  e <- as.brob( exp(1) )
+  e <- as.brob(exp(1))
 
   ml <- e^(bridge_object$logml)
   g_p <- e^(bridge_object$q12)
   g_g <- e^(bridge_object$q22)
   priorTimesLik_p <- e^(bridge_object$q11)
   priorTimesLik_g <- e^(bridge_object$q21)
-  p_p <- priorTimesLik_p/ml
-  p_g <- priorTimesLik_g/ml
+  p_p <- priorTimesLik_p / ml
+  p_g <- priorTimesLik_g / ml
 
   N1 <- length(p_p)
   N2 <- length(g_g)
-  s1 <- N1/(N1 + N2)
-  s2 <- N2/(N1 + N2)
+  s1 <- N1 / (N1 + N2)
+  s2 <- N2 / (N1 + N2)
 
-  f1 <- as.numeric( p_g/(s1*p_g + s2*g_g) )
-  f2 <- as.numeric( g_p/(s1*p_p + s2*g_p) )
-  rho_f2 <- spectrum0.ar( f2 )$spec
+  f1 <- as.numeric(p_g / (s1 * p_g + s2 * g_g))
+  f2 <- as.numeric(g_p / (s1 * p_p + s2 * g_p))
+  rho_f2 <- spectrum0.ar(f2)$spec
 
-  term1 <- 1/N2 * var( f1 ) / mean( f1 )^2
-  term2 <- rho_f2/N1 * var( f2 ) / mean( f2 )^2
+  term1 <- 1 / N2 * var(f1) / mean(f1)^2
+  term2 <- rho_f2 / N1 * var(f2) / mean(f2)^2
 
   re2 <- term1 + term2
 
@@ -74,15 +75,14 @@ error_measures.bridge <- function(bridge_object,...) {
   # convert to percentage error
   percentage <- scales::percent(cv)
   return(list(re2 = re2, cv = cv, percentage = percentage))
-
 }
 
 #' @rdname error_measures
 #' @export
 error_measures.bridge_list <- function(bridge_object, na.rm = TRUE, ...) {
-
-  return(list(min = min(bridge_object$logml, na.rm = na.rm),
-              max = max(bridge_object$logml, na.rm = na.rm),
-              IQR = stats::IQR(bridge_object$logml, na.rm = na.rm)))
-
+  return(list(
+    min = min(bridge_object$logml, na.rm = na.rm),
+    max = max(bridge_object$logml, na.rm = na.rm),
+    IQR = stats::IQR(bridge_object$logml, na.rm = na.rm)
+  ))
 }
