@@ -63,7 +63,7 @@ test_that("subscript out of bounds error", {
   }
   "
   testthat::skip_on_cran()
-  testthat::skip_on_travis()
+  testthat::skip_on_ci()
   testthat::skip_if_not_installed("rstan")
   library("rstan")
   # source("tests/testthat/test_dat.txt")
@@ -80,7 +80,7 @@ test_that("subscript out of bounds error", {
 test_that("bridge_sampler.stanfit multicore works for one-parameter model.", {
 
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
   skip_on_os("windows")
 
   if (require(rstan)) {
@@ -124,7 +124,7 @@ test_that("bridge_sampler.stanfit multicore works for one-parameter model.", {
 
 test_that("turtle example",{
   skip_on_cran()
-  skip_on_travis()
+  skip_on_ci()
 
 
   if (require(rstan)) {
